Requirements
================


System
-----------------

Currently, InferPy requires Python 3.5 or higher. For checking your default Python version, type:


.. code:: bash

    $ python --version

Travis tests are performed on versions 3.5 and 3.6. Go to `https://www.python.org/ <https://www.python.org/>`_
for specific instructions for installing the Python interpreter in your system.


InferPy runs in any OS with the Python interpreter installed. In particular, tests have been carried out
for the systems listed bellow.

- Linux CentOS 7
- Linux Elementary 0.4
- Linux Mint 19
- Linux Ubuntu 14.04 16.04 18.04
- MacOS High Sierra (10.13) and Mojave (10.14)
- Windows 10 Enterprise


Package Dependencies
-------------------------

For a basic usage, InferPy requires the following packages:

.. literalinclude:: ../../requirements/prod.txt
